==> qtjambi-multimedia-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiMultimedia/QMediaDevices_shell.h <==
#ifndef QMEDIADEVICES_SHELL_H
#define QMEDIADEVICES_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qmediadevices.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qaudiodevice.h>
#include <QtMultimedia/qcameradevice.h>
#include <QtJambi/RegistryAPI>


class QMediaDevices_shell : public QMediaDevices, public QtJambiShellInterface
{
public:
    QMediaDevices_shell(QObject* parent0 = nullptr);
    ~QMediaDevices_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QMediaDevices_mshell;
    friend class QMediaDevices_oshell;
};


class QMediaDevices_mshell : public QMediaDevices_shell
{
public:
    using QMediaDevices_shell::QMediaDevices_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QMediaDevices_oshell : public QMediaDevices_mshell
{
public:
    using QMediaDevices_mshell::QMediaDevices_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMediaDevices_access : public QMediaDevices
{
    void __qt_connectNotify_cref_QMetaMethod(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID signal0);
};

#endif // QMEDIADEVICES_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-6.6.3.jar: sources/QtJambiMultimedia/QMediaDevices_shell.h <==
#ifndef QMEDIADEVICES_SHELL_H
#define QMEDIADEVICES_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qmediadevices.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtMultimedia/qaudiodevice.h>
#include <QtMultimedia/qcameradevice.h>
#include <QtJambi/RegistryAPI>


class QMediaDevices_shell : public QMediaDevices, public QtJambiShellInterface
{
public:
    QMediaDevices_shell(QObject* parent0 = nullptr);
    ~QMediaDevices_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMediaDevices_access : public QMediaDevices
{
    void __qt_connectNotify_cref_QMetaMethod(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID signal0);
};

#endif // QMEDIADEVICES_SHELL_H
